@@ -1,16 +1,19 @@
 //! Types for returning SQL type information about queries.
 
-use crate::Database;
 use std::fmt::{self, Debug};
 
-/// The return type of [Executor::describe].
+use crate::database::Database;
+
+/// The return type of [`Executor::describe`].
+///
+/// [`Executor::describe`]: crate::executor::Executor::describe
 #[non_exhaustive]
 pub struct Describe<DB>
 where
     DB: Database + ?Sized,
 {
     /// The expected types for the parameters of the query.
-    pub param_types: Box<[DB::TypeInfo]>,
+    pub param_types: Box<[Option<DB::TypeInfo>]>,
 
     /// The type and table information, if any for the results of the query.
     pub result_columns: Box<[Column<DB>]>,
@@ -38,7 +41,9 @@ where
 {
     pub name: Option<Box<str>>,
     pub table_id: Option<DB::TableId>,
-    pub type_info: DB::TypeInfo,
+    pub type_info: Option<DB::TypeInfo>,
+    /// Whether or not the column cannot be `NULL` (or if that is even knowable).
+    pub non_null: Option<bool>,
 }
 
 impl<DB> Debug for Column<DB>
@@ -51,7 +56,8 @@ where
         f.debug_struct("Column")
             .field("name", &self.name)
             .field("table_id", &self.table_id)
-            .field("type_id", &self.type_info)
+            .field("type_info", &self.type_info)
+            .field("non_null", &self.non_null)
             .finish()
     }
 }
