@@ -1,7 +1,7 @@
 //! Types and traits for encoding values to the database.
 
 use crate::database::Database;
-use crate::types::HasSqlType;
+use crate::types::Type;
 use std::mem;
 
 /// The return type of [Encode::encode].
@@ -21,9 +21,9 @@ where
     DB: Database + ?Sized,
 {
     /// Writes the value of `self` into `buf` in the expected format for the database.
-    fn encode(&self, buf: &mut Vec<u8>);
+    fn encode(&self, buf: &mut DB::RawBuffer);
 
-    fn encode_nullable(&self, buf: &mut Vec<u8>) -> IsNull {
+    fn encode_nullable(&self, buf: &mut DB::RawBuffer) -> IsNull {
         self.encode(buf);
 
         IsNull::No
@@ -36,14 +36,15 @@ where
 
 impl<T: ?Sized, DB> Encode<DB> for &'_ T
 where
-    DB: Database + HasSqlType<T>,
+    DB: Database,
+    T: Type<DB>,
     T: Encode<DB>,
 {
-    fn encode(&self, buf: &mut Vec<u8>) {
+    fn encode(&self, buf: &mut DB::RawBuffer) {
         (*self).encode(buf)
     }
 
-    fn encode_nullable(&self, buf: &mut Vec<u8>) -> IsNull {
+    fn encode_nullable(&self, buf: &mut DB::RawBuffer) -> IsNull {
         (*self).encode_nullable(buf)
     }
 
@@ -54,15 +55,16 @@ where
 
 impl<T, DB> Encode<DB> for Option<T>
 where
-    DB: Database + HasSqlType<T>,
+    DB: Database,
+    T: Type<DB>,
     T: Encode<DB>,
 {
-    fn encode(&self, buf: &mut Vec<u8>) {
+    fn encode(&self, buf: &mut DB::RawBuffer) {
         // Forward to [encode_nullable] and ignore the result
         let _ = self.encode_nullable(buf);
     }
 
-    fn encode_nullable(&self, buf: &mut Vec<u8>) -> IsNull {
+    fn encode_nullable(&self, buf: &mut DB::RawBuffer) -> IsNull {
         if let Some(self_) = self {
             self_.encode(buf);
 
@@ -73,10 +75,6 @@ where
     }
 
     fn size_hint(&self) -> usize {
-        if self.is_some() {
-            (*self).size_hint()
-        } else {
-            0
-        }
+        self.as_ref().map_or(0, Encode::size_hint)
     }
 }
