@@ -2,7 +2,7 @@ use byteorder::LittleEndian;
 
 use crate::io::Buf;
 use crate::mysql::io::BufExt;
-use crate::mysql::protocol::{Decode, FieldFlags, TypeId};
+use crate::mysql::protocol::{FieldFlags, TypeId};
 
 // https://dev.mysql.com/doc/dev/mysql-server/8.0.12/page_protocol_com_query_response_text_resultset_column_definition.html
 // https://mariadb.com/kb/en/resultset/#column-definition-packet
@@ -27,8 +27,14 @@ pub struct ColumnDefinition {
     pub decimals: u8,
 }
 
-impl Decode for ColumnDefinition {
-    fn decode(mut buf: &[u8]) -> crate::Result<Self> {
+impl ColumnDefinition {
+    pub fn name(&self) -> Option<&str> {
+        self.column_alias.as_deref().or(self.column.as_deref())
+    }
+}
+
+impl ColumnDefinition {
+    pub(crate) fn read(mut buf: &[u8]) -> crate::Result<Self> {
         // catalog : string<lenenc>
         let catalog = buf.get_str_lenenc::<LittleEndian>()?;
 
