@@ -1,7 +1,8 @@
 use std::{marker::PhantomData, time::Duration};
 
 use super::Pool;
-use crate::connection::{Connect, Connection};
+use crate::connection::Connect;
+use crate::database::Database;
 
 /// Builder for [Pool].
 pub struct Builder<C> {
@@ -9,7 +10,10 @@ pub struct Builder<C> {
     options: Options,
 }
 
-impl<C> Builder<C> {
+impl<C> Builder<C>
+where
+    C: Connect,
+{
     /// Get a new builder with default options.
     ///
     /// See the source of this method for current defaults.
@@ -43,7 +47,7 @@ impl<C> Builder<C> {
 
     /// Set the amount of time to attempt connecting to the database.
     ///
-    /// If this timeout elapses, [Pool::acquire] will return an error.
+    /// If this timeout elapses, [`Pool::acquire`] will return an error.
     pub fn connect_timeout(mut self, connect_timeout: Duration) -> Self {
         self.options.connect_timeout = connect_timeout;
         self
@@ -53,8 +57,11 @@ impl<C> Builder<C> {
     ///
     /// When the pool is built, this many connections will be automatically spun up.
     ///
-    /// If any connection is reaped by [max_lifetime] or [idle_timeout] and it brings
+    /// If any connection is reaped by [`max_lifetime`] or [`idle_timeout`] and it brings
     /// the connection count below this amount, a new connection will be opened to replace it.
+    ///
+    /// [`max_lifetime`]: #method.max_lifetime
+    /// [`idle_timeout`]: #method.idle_timeout
     pub fn min_size(mut self, min_size: u32) -> Self {
         self.options.min_size = min_size;
         self
@@ -64,7 +71,7 @@ impl<C> Builder<C> {
     ///
     /// Any connection with a lifetime greater than this will be closed.
     ///
-    /// When set to `None`, all connections live until either reaped by [idle_timeout]
+    /// When set to `None`, all connections live until either reaped by [`idle_timeout`]
     /// or explicitly disconnected.
     ///
     /// Infinite connections are not recommended due to the unfortunate reality of memory/resource
@@ -72,6 +79,8 @@ impl<C> Builder<C> {
     /// (even if only once daily) to allow the database the opportunity to clean up data structures
     /// (parse trees, query metadata caches, thread-local storage, etc.) that are associated with a
     /// session.
+    ///
+    /// [`idle_timeout`]: #method.idle_timeout
     pub fn max_lifetime(mut self, max_lifetime: impl Into<Option<Duration>>) -> Self {
         self.options.max_lifetime = max_lifetime.into();
         self
@@ -87,10 +96,12 @@ impl<C> Builder<C> {
         self
     }
 
-    /// If true, the health of a connection will be verified by a call to `Connection::ping`
+    /// If true, the health of a connection will be verified by a call to [`Connection::ping`]
     /// before returning the connection.
     ///
     /// Defaults to `true`.
+    ///
+    /// [`Connection::ping`]: crate::connection::Connection::ping
     pub fn test_on_acquire(mut self, test: bool) -> Self {
         self.options.test_on_acquire = test;
         self
@@ -98,17 +109,23 @@ impl<C> Builder<C> {
 
     /// Spin up the connection pool.
     ///
-    /// If [min_size] was set to a non-zero value, that many connections will be immediately
+    /// If [`min_size`] was set to a non-zero value, that many connections will be immediately
     /// opened and placed into the pool.
+    ///
+    /// [`min_size`]: #method.min_size
     pub async fn build(self, url: &str) -> crate::Result<Pool<C>>
     where
-        C: Connection + Connect<Connection = C>,
+        C: Connect,
     {
-        Pool::with_options(url, self.options).await
+        Pool::<C>::with_options(url, self.options).await
     }
 }
 
-impl<C> Default for Builder<C> {
+impl<C, DB> Default for Builder<C>
+where
+    C: Connect<Database = DB>,
+    DB: Database<Connection = C>,
+{
     fn default() -> Self {
         Self::new()
     }
